//@line 4 "/builds/slave/tb-rel-c-beta-lx_rpk_3-0000000/l10n/et/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-lx_rpk_3-0000000/l10n/et/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-lx_rpk_3-0000000/l10n/et/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/slave/tb-rel-c-beta-lx_rpk_3-0000000/l10n/et/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "et");

//@line 23 "/builds/slave/tb-rel-c-beta-lx_rpk_3-0000000/l10n/et/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Aastapäevad,Ideed,Isiklik,Järeltegevuseks,Kingitused,Kliendid,Konkurents,Kõned,Lemmikud,Ostjad,Probleemid,Projektid,Puhkus,Pühad,Reisimine,Seisund,Sünnipäevad,Tarnijad,Tähtpäevad,Varia,Äri");
